"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const errors_1 = require("./errors");
describe('errors', () => {
    it('should raise an Unauthorized error', () => {
        expect(new errors_1.UnauthorizedError()).toMatchObject({
            headers: {
                'WWW-Authenticate': 'Bearer realm="api"',
            },
            message: 'Unauthorized',
            name: 'UnauthorizedError',
            status: 401,
            statusCode: 401,
        });
    });
    it('should raise an Invalid Request error', () => {
        expect(new errors_1.InvalidRequestError()).toMatchObject({
            code: 'invalid_request',
            headers: {
                'WWW-Authenticate': 'Bearer realm="api", error="invalid_request", error_description="Invalid Request"',
            },
            message: 'Invalid Request',
            name: 'InvalidRequestError',
            status: 400,
            statusCode: 400,
        });
    });
    it('should raise an Invalid Request error with a custom message', () => {
        expect(new errors_1.InvalidRequestError('Custom Message')).toMatchObject({
            code: 'invalid_request',
            headers: {
                'WWW-Authenticate': 'Bearer realm="api", error="invalid_request", error_description="Custom Message"',
            },
            message: 'Custom Message',
            name: 'InvalidRequestError',
            status: 400,
            statusCode: 400,
        });
    });
    it('should avoid nested double quotes in header', () => {
        expect(new errors_1.InvalidRequestError('expected "foo" got "bar"')).toMatchObject({
            code: 'invalid_request',
            headers: {
                'WWW-Authenticate': `Bearer realm="api", error="invalid_request", error_description="expected 'foo' got 'bar'"`,
            },
            message: 'expected "foo" got "bar"',
            name: 'InvalidRequestError',
            status: 400,
            statusCode: 400,
        });
    });
    it('should raise an Invalid Token error', () => {
        expect(new errors_1.InvalidTokenError()).toMatchObject({
            code: 'invalid_token',
            headers: {
                'WWW-Authenticate': 'Bearer realm="api", error="invalid_token", error_description="Invalid Token"',
            },
            message: 'Invalid Token',
            name: 'InvalidTokenError',
            status: 401,
            statusCode: 401,
        });
    });
    it('should raise an Insufficient Scope error', () => {
        expect(new errors_1.InsufficientScopeError(['foo', 'bar'])).toMatchObject({
            code: 'insufficient_scope',
            headers: {
                'WWW-Authenticate': 'Bearer realm="api", error="insufficient_scope", error_description="Insufficient Scope", scope="foo bar"',
            },
            message: 'Insufficient Scope',
            name: 'InsufficientScopeError',
            status: 403,
            statusCode: 403,
        });
    });
});
